@@ -3,5 +3,5 @@ context("Test: getMetaGenomeSummary()")
 test_that("The getMetaGenomeSummary() interface works properly..",{
     skip_on_cran()
     skip_on_travis()
-    expect_output(getMetaGenomeSummary())
+    expect_false(nrow(getMetaGenomeSummary()) == 0)
 })
